@@ -213,6 +213,11 @@ class TestBootSteps(TestCaseWithFixtures):
         expected = ['make_uImage', 'make_uInitrd', 'make_boot_script']
         self.assertEqual(expected, self.funcs_calls)
 
+    def test_snowball_sd_steps(self):
+        self.make_boot_files(boards.SnowballSdConfig)
+        expected = ['make_uImage', 'make_boot_script']
+        self.assertEqual(expected, self.funcs_calls)
+
     def test_panda_steps(self):
         self.mock_set_appropriate_serial_tty(boards.PandaConfig)
         self.make_boot_files(boards.PandaConfig)
@@ -330,6 +335,16 @@ class TestGetSfdiskCmd(TestCase):
             '1,8191,0xDA\n8192,106496,0x0C,*\n114688,,,-',
             boards.Mx5Config.get_sfdisk_cmd())
 
+    def test_snowball_sd(self):
+        self.assertEqual(
+            '63,106432,0x0C,*\n106496,,,-',
+            boards.SnowballSdConfig.get_sfdisk_cmd())
+
+    def test_snowball_emmc(self):
+        self.assertEqual(
+            '256,7936,0xDA\n8192,106496,0x0C,*\n114688,,,-',
+            boards.SnowballEmmcConfig.get_sfdisk_cmd())
+
     def test_smdkv310(self):
         self.assertEquals(
             '1,8191,0xDA\n8192,106496,0x0C,*\n114688,,,-',
@@ -393,6 +408,23 @@ class TestGetBootCmd(TestCase):
                        'bootm 0x00100000 0x08000000'}
         self.assertEqual(expected, boot_commands)
 
+    def test_snowball_emmc(self):
+        boot_commands = board_configs['snowball_emmc']._get_boot_env(
+            is_live=False, is_lowmem=False, consoles=[],
+            rootfs_uuid="deadbeef", d_img_data=None)
+        expected = {
+            'bootargs': 'console=tty0 console=ttyAMA2,115200n8  '
+                        'root=UUID=deadbeef rootwait ro earlyprintk '
+                        'rootdelay=1 fixrtc nocompcache mem=96M@0 '
+                        'mem_modem=32M@96M mem=44M@128M pmem=22M@172M '
+                        'mem=30M@194M mem_mali=32M@224M pmem_hwb=54M@256M '
+                        'hwmem=48M@302M mem=152M@360M',
+            'bootcmd': 'fatload mmc 1:1 0x00100000 uImage; '
+                       'fatload mmc 1:1 0x08000000 uInitrd; '
+                       'bootm 0x00100000 0x08000000'}
+        self.assertEqual(expected, boot_commands)
+
+
     def test_panda(self):
         # XXX: To fix bug 697824 we have to change class attributes of our
         # OMAP board configs, and some tests do that so to make sure they
@@ -405,7 +437,7 @@ class TestGetBootCmd(TestCase):
         expected = {
             'bootargs': 'console=tty0 console=ttyO2,115200n8  '
                         'root=UUID=deadbeef rootwait ro earlyprintk fixrtc '
-                        'nocompcache vram=32M omapfb.vram=0:8M '
+                        'nocompcache vram=48M omapfb.vram=0:24M '
                         'mem=456M@0x80000000 mem=512M@0xA0000000',
             'bootcmd': 'fatload mmc 0:1 0x80200000 uImage; '
                        'fatload mmc 0:1 0x81600000 uInitrd; '
@@ -465,9 +497,7 @@ class TestGetBootCmd(TestCase):
         expected = {
             'bootargs': 'console=tty0 console=ttyO2,115200n8  '
                         'root=UUID=deadbeef rootwait ro earlyprintk '
-                        'mpurate=500 vram=12M '
-                        'omapfb.mode=dvi:1024x768MR-16@60 '
-                        'omapdss.def_disp=dvi',
+                        'mpurate=${mpurate} vram=12M',
             'bootcmd': 'fatload mmc 0:1 0x80000000 uImage; '
                        'fatload mmc 0:1 0x81600000 uInitrd; '
                        'fatload mmc 0:1 0x815f0000 board.dtb; '
@@ -628,6 +658,8 @@ class TestBoards(TestCaseWithFixtures):
         file1 = self.createTempFileAsFixture(prefix)
         file2 = self.createTempFileAsFixture(prefix)
         directory = os.path.dirname(file1)
+        assert directory == os.path.dirname(file2), (
+            "file1 and file2 should be in the same directory")
         self.assertRaises(
             ValueError, _get_file_matching, '%s/%s*' % (directory, prefix))
 
@@ -812,8 +844,8 @@ class TestCreatePartitions(TestCaseWithFixtures):
     def test_run_sfdisk_commands(self):
         tmpfile = self.createTempFileAsFixture()
         proc = cmd_runner.run(
-            ['qemu-img', 'create', '-f', 'raw', tmpfile, '10M'],
-            stdout=subprocess.PIPE)
+            ['dd', 'of=%s' % tmpfile, 'bs=1', 'seek=10M', 'count=0'],
+            stderr=open('/dev/null', 'w'))
         proc.communicate()
         stdout, stderr = run_sfdisk_commands(
             '2,16063,0xDA', HEADS, SECTORS, '', tmpfile, as_root=False,
@@ -846,6 +878,9 @@ class TestPartitionSetup(TestCaseWithFixtures):
         return self._create_qemu_img_with_partitions(
             '16384,15746,0x0C,*\n32768,,,-')
 
+    def test_convert_size_no_suffix(self):
+        self.assertEqual(524288, convert_size_to_bytes('524288'))
+
     def test_convert_size_in_kbytes_to_bytes(self):
         self.assertEqual(512 * 1024, convert_size_to_bytes('512K'))
 
@@ -899,8 +934,8 @@ class TestPartitionSetup(TestCaseWithFixtures):
     def _create_qemu_img_with_partitions(self, sfdisk_commands):
         tmpfile = self.createTempFileAsFixture()
         proc = cmd_runner.run(
-            ['qemu-img', 'create', '-f', 'raw', tmpfile, '30M'],
-            stdout=subprocess.PIPE)
+            ['dd', 'of=%s' % tmpfile, 'bs=1', 'seek=30M', 'count=0'],
+            stderr=open('/dev/null', 'w'))
         proc.communicate()
         stdout, stderr = run_sfdisk_commands(
             sfdisk_commands, HEADS, SECTORS, '', tmpfile, as_root=False,
@@ -958,7 +993,7 @@ class TestPartitionSetup(TestCaseWithFixtures):
     def test_setup_partitions_for_image_file(self):
         # In practice we could pass an empty image file to setup_partitions,
         # but here we mock Popen() and thanks to that the image is not setup
-        # (via qemu-img) inside setup_partitions.  That's why we pass an
+        # (via dd) inside setup_partitions.  That's why we pass an
         # already setup image file.
         tmpfile = self._create_tmpfile()
         popen_fixture = self.useFixture(MockCmdRunnerPopenFixture())
@@ -981,7 +1016,7 @@ class TestPartitionSetup(TestCaseWithFixtures):
             'root', 'ext3', True, True, True)
         self.assertEqual(
              # This is the call that would create a 2 GiB image file.
-            ['qemu-img create -f raw %s 2147483648' % tmpfile,
+            ['dd of=%s bs=1 seek=2147483648 count=0' % tmpfile,
              # This call would partition the image file.
              '%s sfdisk --force -D -uS -H %s -S %s -C 1024 %s' % (
                  sudo_args, HEADS, SECTORS, tmpfile),
@@ -1392,7 +1427,7 @@ class TestInstallHWPack(TestCaseWithFixtures):
         prefer_dir = preferred_tools_dir()
 
         install_hwpacks(
-            chroot_dir, tmp_dir, prefer_dir, force_yes, 'hwpack1.tgz',
+            chroot_dir, tmp_dir, prefer_dir, force_yes, [], 'hwpack1.tgz',
             'hwpack2.tgz')
         linaro_hwpack_install = find_command(
             'linaro-hwpack-install', prefer_dir=prefer_dir)
@@ -1506,7 +1541,7 @@ class TestInstallHWPack(TestCaseWithFixtures):
         exception_caught = False
         try:
             install_hwpacks(
-                'chroot', '/tmp/dir', preferred_tools_dir(), force_yes,
+                'chroot', '/tmp/dir', preferred_tools_dir(), force_yes, [],
                 'hwp.tgz', 'hwp2.tgz')
         except:
             exception_caught = True
